@@ -9,15 +9,15 @@
 #  ifndef MYSOFA_EXPORT
 #    ifdef mysofa_shared_EXPORTS
         /* We are building this library */
-#      define MYSOFA_EXPORT __attribute__((visibility("default")))
+#      define MYSOFA_EXPORT 
 #    else
         /* We are using this library */
-#      define MYSOFA_EXPORT __attribute__((visibility("default")))
+#      define MYSOFA_EXPORT 
 #    endif
 #  endif
 
 #  ifndef MYSOFA_NO_EXPORT
-#    define MYSOFA_NO_EXPORT __attribute__((visibility("hidden")))
+#    define MYSOFA_NO_EXPORT 
 #  endif
 #endif
 
